SoapHandler

Trait SoapHandler 

pub trait SoapHandler:
    Send
    + Sync
    + 'static {
    // Required method
    fn handle<'life0, 'async_trait>(
        &'life0 self,
        body: Bytes,
    ) -> Pin<Box<dyn Future<Output = Result<Bytes, SoapFault>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn handle_with_headers<'life0, 'life1, 'async_trait>(
        &'life0 self,
        body: Bytes,
        _headers: &'life1 [Bytes],
    ) -> Pin<Box<dyn Future<Output = Result<Bytes, SoapFault>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
}
A SOAP operation handler that receives the Body first child element as self-contained XML bytes (all ancestor namespace declarations re-emitted on the root) and returns response body XML bytes or a SoapFault.

Required Methods

fn handle<'life0, 'async_trait>( &'life0 self, body: Bytes, ) -> Pin<Box<dyn Future<Output = Result<Bytes, SoapFault>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Provided Methods

fn handle_with_headers<'life0, 'life1, 'async_trait>( &'life0 self, body: Bytes, _headers: &'life1 [Bytes], ) -> Pin<Box<dyn Future<Output = Result<Bytes, SoapFault>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Handle a request with access to the SOAP header element fragments (each is the raw bytes of one direct child of <Header>). Defaults to ignoring headers and calling handle. Handlers needing WS-Addressing/WS-Security header data override this.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F, Fut> SoapHandler for FnHandler<F>
where F: Fn(Bytes) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Bytes, SoapFault>> + Send + 'static,